.. module:: pymeasure.instruments.siglenttechnologies

####################
Siglent Technologies
####################

This section contains specific documentation on the Siglent Technologies instruments that are implemented. If you are interested in an instrument not included, please consider :doc:`adding the instrument </dev/adding_instruments/index>`.

.. toctree::
   :maxdepth: 2

   siglent_spdbase
   siglent_spd1168x
   siglent_spd1305x